@@ -33,8 +33,8 @@ provides: [Core, MooTools, Type, typeOf, instanceOf, Native]
 (function(){
 
 this.MooTools = {
-	version: '1.3.1',
-	build: 'af48c8d589f43f32212f9bb8ff68a127e6a3ba6c'
+	version: '1.3.2',
+	build: 'c9f1ff10e9e7facb65e9481049ed1b450959d587'
 };
 
 // typeOf, instanceOf
@@ -398,7 +398,7 @@ String.extend('uniqueID', function(){
 
 
 
-}).call(this);
+})();
 
 
 /*
@@ -419,13 +419,7 @@ provides: Array
 
 Array.implement({
 
-	invoke: function(methodName){
-		var args = Array.slice(arguments, 1);
-		return this.map(function(item){
-			return item[methodName].apply(item, args);
-		});
-	},
-
+	/*<!ES5>*/
 	every: function(fn, bind){
 		for (var i = 0, l = this.length; i < l; i++){
 			if ((i in this) && !fn.call(bind, this[i], i, this)) return false;
@@ -441,12 +435,6 @@ Array.implement({
 		return results;
 	},
 
-	clean: function(){
-		return this.filter(function(item){
-			return item != null;
-		});
-	},
-
 	indexOf: function(item, from){
 		var len = this.length;
 		for (var i = (from < 0) ? Math.max(0, len + from) : from || 0; i < len; i++){
@@ -469,6 +457,20 @@ Array.implement({
 		}
 		return false;
 	},
+	/*</!ES5>*/
+
+	clean: function(){
+		return this.filter(function(item){
+			return item != null;
+		});
+	},
+
+	invoke: function(methodName){
+		var args = Array.slice(arguments, 1);
+		return this.map(function(item){
+			return item[methodName].apply(item, args);
+		});
+	},
 
 	associate: function(keys){
 		var obj = {}, length = Math.min(this.length, keys.length);
@@ -748,6 +750,7 @@ Function.implement({
 		return null;
 	},
 
+	/*<!ES5>*/
 	bind: function(bind){
 		var self = this,
 			args = (arguments.length > 1) ? Array.slice(arguments, 1) : null;
@@ -758,6 +761,7 @@ Function.implement({
 			return self.apply(bind, args || arguments);
 		};
 	},
+	/*</!ES5>*/
 
 	pass: function(args, bind){
 		var self = this;
@@ -806,7 +810,7 @@ Object.extend({
 		var results = {};
 		for (var i = 0, l = keys.length; i < l; i++){
 			var k = keys[i];
-			results[k] = object[k];
+			if (k in object) results[k] = object[k];
 		}
 		return results;
 	},
@@ -821,9 +825,10 @@ Object.extend({
 
 	filter: function(object, fn, bind){
 		var results = {};
-		Object.each(object, function(value, key){
-			if (fn.call(bind, value, key, object)) results[key] = value;
-		});
+		for (var key in object){
+			var value = object[key];
+			if (hasOwnProperty.call(object, key) && fn.call(bind, value, key, object)) results[key] = value;
+		}
 		return results;
 	},
 
@@ -1016,7 +1021,7 @@ Class.Mutators = {
 	}
 };
 
-}).call(this);
+})();
 
 
 /*
@@ -1137,7 +1142,7 @@ this.Options = new Class({
 
 });
 
-}).call(this);
+})();
 
 
 /*
@@ -1213,5 +1218,5 @@ JSON.decode = function(string, secure){
 	return eval('(' + string + ')');
 };
 
-}).call(this);
+})();
 
